@@ -8,8 +8,13 @@ logLik.grpreg <- function(object, df.method=c("default","active"), REML=FALSE, .
     RSS <- object$loss
     l <- -n/2 * (log(2*pi) + log(RSS) - log(rdf)) - rdf/2
     df <- df + 1
+  } else if (object$family=="binomial") {
+    l <- -1*object$loss
+  } else if (object$family=="poisson") {
+    y <- object$y
+    ind <- y != 0
+    l <- -object$loss + sum(y[ind]*log(y[ind])) - sum(y) - sum(lfactorial(y))
   }
-  if (object$family=="binomial") l <- -1*object$loss
   
   val <- l
   attr(val,"df") <- df
